@@ -28,8 +28,8 @@ has version => (
 
 has json => (
     is      => 'ro',
-    isa     => 'JSON::XS',
-    default => sub { JSON::XS->new->allow_nonref->utf8->canonical },
+    isa     => JSON::MaybeXS::JSON(),
+    default => sub { JSON::MaybeXS->new->allow_nonref->utf8->canonical },
 );
 
 sub retrieve_all             { shift->_action( 'PONAPI::DAO::Request::RetrieveAll'            , @_ ) }
@@ -82,7 +82,7 @@ PONAPI::DAO - Data Abstraction Object class
 
 =head1 VERSION
 
-version 0.003000
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -571,7 +571,7 @@ Brian Fraser <hugmeir@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2017 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
