@@ -2,7 +2,7 @@
 package PONAPI::DAO::Request;
 
 use Moose;
-use JSON::XS;
+use JSON::MaybeXS;
 
 use PONAPI::Document;
 
@@ -39,8 +39,8 @@ has is_valid => (
 
 has json => (
     is      => 'ro',
-    isa     => 'JSON::XS',
-    default => sub { JSON::XS->new->allow_nonref->utf8->canonical },
+    isa     => JSON::MaybeXS::JSON(),
+    default => sub { JSON::MaybeXS->new->allow_nonref->utf8->canonical },
 );
 
 sub BUILDARGS {
@@ -173,7 +173,7 @@ PONAPI::DAO::Request - DAO request class
 
 =head1 VERSION
 
-version 0.003000
+version 0.003001
 
 =head1 AUTHORS
 
@@ -195,7 +195,7 @@ Brian Fraser <hugmeir@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2017 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
