@@ -4,7 +4,7 @@ package PONAPI::Exception;
 use Moose;
 use Moose::Util qw/find_meta/;
 
-use JSON::XS;
+use JSON::MaybeXS;
 
 sub throw {
   my $class_or_obj = shift;
@@ -111,7 +111,7 @@ sub _handle_exception_obj {
     ) {
         my $class      = find_meta( $e->class_name );
         my $attribute  = $class->get_attribute( $e->attribute_name );
-        my $value_nice = JSON::XS->new->allow_nonref->utf8->canonical->encode( $e->value );
+        my $value_nice = JSON::MaybeXS->new->allow_nonref->utf8->canonical->encode( $e->value );
 
         if ( !$attribute ) {
             my $attr = $e->attribute_name;
@@ -162,7 +162,7 @@ PONAPI::Exception - Exceptions for PONAPI::Server
 
 =head1 VERSION
 
-version 0.003000
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -239,7 +239,7 @@ Brian Fraser <hugmeir@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2017 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
