@@ -4,14 +4,14 @@ package PONAPI::Server;
 use strict;
 use warnings;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.003001';
 
 use Plack::Request;
 use Plack::Response;
 use HTTP::Headers::ActionPack;
-use Module::Runtime    ();
-use JSON::XS           ();
-use URI::Escape        qw( uri_unescape );
+use Module::Runtime ();
+use JSON::MaybeXS;
+use URI::Escape qw( uri_unescape );
 
 use PONAPI::Server::ConfigReader;
 use PONAPI::Names qw( check_name );
@@ -242,6 +242,9 @@ sub _ponapi_query_params {
     for my $k ( keys %{ $query_params } ) {
         my ( $p, $f ) = $k =~ /^ (\w+?) (?:\[(\w+)\])? $/x;
 
+        # key not matched
+        die(ERR_BAD_REQ_PARAMS) unless defined $p;
+
         # valid parameter names
         die(ERR_BAD_REQ_PARAMS)
             unless grep { $p eq $_ } qw< fields filter page include sort >;
@@ -260,8 +263,7 @@ sub _ponapi_query_params {
 
         # check we have values for a given key
         # (for 'fields' an empty list is valid)
-        die(ERR_BAD_REQ)
-            if $p ne 'fields' and exists $query_params->{$k} and !@values;
+        die(ERR_BAD_REQ) if $p ne 'fields' and !@values;
 
         # values passed on in array-ref
         grep { $p eq $_ } qw< fields filter >
@@ -290,7 +292,7 @@ sub _ponapi_data {
     die(ERR_BAD_REQ) if _is_get_like($req);
 
     my $body;
-    eval { $body = JSON::XS::decode_json( $req->content ); 1 };
+    eval { $body = JSON::MaybeXS::decode_json( $req->content ); 1 };
 
     die(ERR_BAD_REQ) unless $body and ref $body eq 'HASH' and exists $body->{data};
 
@@ -359,7 +361,7 @@ sub _response {
         if $self->{'ponapi.send_version_header'};
 
     if ( ref $content ) {
-        my $enc_content = JSON::XS::encode_json $content;
+        my $enc_content = JSON::MaybeXS::encode_json $content;
         $res->content_length( length($enc_content) );
         $res->content_type( $self->{'ponapi.mediatype'} );
         $res->content($enc_content) unless $is_head;
@@ -396,7 +398,7 @@ PONAPI::Server - PONAPI - Perl implementation of {JSON:API} (http://jsonapi.org/
 
 =head1 VERSION
 
-version 0.003000
+version 0.003001
 
 =head1 SYNOPSIS
 
@@ -442,7 +444,7 @@ Brian Fraser <hugmeir@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Mickey Nasriachi, Stevan Little, Brian Fraser.
+This software is copyright (c) 2017 by Mickey Nasriachi, Stevan Little, Brian Fraser.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
